Automated subcortical brain segmentation pipeline

##Background
This package provides trained 3D U-Net model for subcortical brain segmentation


##Tutorial using SubBrainSegment

###Github:
1. Download from github

2. Install Python 3 and dependencies:
* numpy>=1.17.4
* nibabel>=2.5.1
* tables>=3.6.1
* tensorflow-gpu==1.14.0
* Keras == 2.0.8
* h5py==2.9.0
* [SimpleITK](https://simpleitk.readthedocs.io/en/master/gettingStarted.html)
* [keras-contrib](https://github.com/keras-team/keras-contrib)

3.



###As a python module:
